==> scanbot_sdk-2.8.0.tar.gz: ios/Classes/Extensions/SDK/Machine Codes/SBSDKBarcodeDocumentType.swift <==
//
//  SBSDKBarcodeDocumentType.swift
//  scanbot_sdk
//
//  Created by Sarbjyot Singh Chahal on 23.11.21.
//

import Foundation
import ScanbotSDK

extension SBSDKBarcodeDocumentType {
    static func fromArguments(_ arguments: [String: Any]) -> [SBSDKBarcodeDocumentType]? {
        if let stringArray = arguments["acceptedDocumentFormats"] as? [String] {
            let barcodes = stringArray.compactMap({ SBSDKBarcodeDocumentType.from(string: $0) })
            return barcodes
        }
        return nil
    }

    static func from(string: String) -> SBSDKBarcodeDocumentType? {
        switch string {
        case "AAMVA": return SBSDKBarcodeDocumentTypeAAMVA;
        case "BOARDING_PASS": return SBSDKBarcodeDocumentTypeBoardingPass;
        case "DE_MEDICAL_PLAN": return SBSDKBarcodeDocumentTypeMedicalPlan;
        case "DISABILITY_CERTIFICATE": return SBSDKBarcodeDocumentTypeDisabilityCertificate;
        case "ID_CARD_PDF_417": return SBSDKBarcodeDocumentTypeIDCardPDF417;
        case "SEPA": return SBSDKBarcodeDocumentTypeSEPA;
        case "SWISS_QR": return SBSDKBarcodeDocumentTypeSwissQR;
        case "VCARD": return SBSDKBarcodeDocumentTypeVCard;
        default: return nil
        }
    }

    var encodedString: String? {
        switch self {
        case SBSDKBarcodeDocumentTypeAAMVA: return "AAMVA";
        case SBSDKBarcodeDocumentTypeBoardingPass: return "BOARDING_PASS";
        case SBSDKBarcodeDocumentTypeMedicalPlan: return "DE_MEDICAL_PLAN";
        case SBSDKBarcodeDocumentTypeDisabilityCertificate: return "DISABILITY_CERTIFICATE";
        case SBSDKBarcodeDocumentTypeIDCardPDF417: return "ID_CARD_PDF_417";
        case SBSDKBarcodeDocumentTypeSEPA: return "SEPA";
        case SBSDKBarcodeDocumentTypeSwissQR: return "SWISS_QR";
        case SBSDKBarcodeDocumentTypeVCard: return "VCARD";
        default: return nil
        }
    }
}

==> scanbot_sdk-2.9.0.tar.gz: ios/Classes/Extensions/SDK/Machine Codes/SBSDKBarcodeDocumentType.swift <==
//
//  SBSDKBarcodeDocumentType.swift
//  scanbot_sdk
//
//  Created by Sarbjyot Singh Chahal on 23.11.21.
//

import Foundation
import ScanbotSDK

extension SBSDKBarcodeDocumentType {
    static func fromArguments(_ arguments: [String: Any]) -> [SBSDKBarcodeDocumentType]? {
        if let stringArray = arguments["acceptedDocumentFormats"] as? [String] {
            let barcodes = stringArray.compactMap({ SBSDKBarcodeDocumentType.from(string: $0) })
            return barcodes
        }
        return nil
    }

    static func from(string: String) -> SBSDKBarcodeDocumentType? {
        switch string {
        case "AAMVA": return SBSDKBarcodeDocumentTypeAAMVA;
        case "BOARDING_PASS": return SBSDKBarcodeDocumentTypeBoardingPass;
        case "DE_MEDICAL_PLAN": return SBSDKBarcodeDocumentTypeMedicalPlan;
        case "MEDICAL_CERTIFICATE": return SBSDKBarcodeDocumentTypeMedicalCertificate;
        case "ID_CARD_PDF_417": return SBSDKBarcodeDocumentTypeIDCardPDF417;
        case "SEPA": return SBSDKBarcodeDocumentTypeSEPA;
        case "SWISS_QR": return SBSDKBarcodeDocumentTypeSwissQR;
        case "VCARD": return SBSDKBarcodeDocumentTypeVCard;
        default: return nil
        }
    }

    var encodedString: String? {
        switch self {
        case SBSDKBarcodeDocumentTypeAAMVA: return "AAMVA";
        case SBSDKBarcodeDocumentTypeBoardingPass: return "BOARDING_PASS";
        case SBSDKBarcodeDocumentTypeMedicalPlan: return "DE_MEDICAL_PLAN";
        case SBSDKBarcodeDocumentTypeMedicalCertificate: return "MEDICAL_CERTIFICATE";
        case SBSDKBarcodeDocumentTypeIDCardPDF417: return "ID_CARD_PDF_417";
        case SBSDKBarcodeDocumentTypeSEPA: return "SEPA";
        case SBSDKBarcodeDocumentTypeSwissQR: return "SWISS_QR";
        case SBSDKBarcodeDocumentTypeVCard: return "VCARD";
        default: return nil
        }
    }
}
